#!/bin/bash -e

source `dirname $0`/env.sh
pushd ${BASE_DIR}

echo "Building Voice AppSizer iOS"
APP_DIR="AppSizer"
APP_SCHEME="AppSizer"
PROJECT_FILE="AppSizer/AppSizer.xcodeproj/project.pbxproj"
SCHEME_FILE="AppSizer/AppSizer.xcodeproj/xcshareddata/xcschemes/AppSizer.xcscheme"
EXPORT_OPTIONS_PLIST="AppSizer/AppSizer/ExportOptions/enterprise.plist"

WORKSPACE=TwilioVoice.xcworkspace
ARCHIVE_PATH="${ARCHIVE_DIR}/${APP_SCHEME}.xcarchive"

BITCODE_MODE=marker
if [ "${CONFIGURATION}" = "Release" ]; then
  BITCODE_MODE=bitcode
fi

mkdir -p ${ARCHIVE_PATH}

xcodebuild \
  -workspace "TwilioVoiceClient/${WORKSPACE}" \
  -scheme ${APP_SCHEME} \
  -derivedDataPath ${DERIVED_DATA_DIR} \
  -configuration ${CONFIGURATION} \
  -sdk iphoneos \
  -parallelizeTargets \
  -archivePath "${ARCHIVE_PATH}" \
  ONLY_ACTIVE_ARCH=NO \
  BITCODE_GENERATION_MODE=${BITCODE_MODE} \
  archive

xcodebuild \
  -exportArchive \
  -archivePath "${ARCHIVE_PATH}" \
  -exportPath "${IPA_DIR}" \
  -exportOptionsPlist ${EXPORT_OPTIONS_PLIST}

# Generate the sizing report
export BASE_VERSION=$SDK_RELEASE_VERSION
./Scripts/env.rb ./Scripts/generate-size-report.rb

popd