#!/bin/bash -e -x

export PATH=/usr/local/bin:$PATH

if (($# != 2)); then
  echo "Usage $0 <test_host> <test_target>"
  exit 1
fi

TEST_HOST=$1
TEST_TARGET=$2

TEST_ARTIFACT=${CONFIGURATION}-iphoneos-${TEST_HOST}.zip

rm -rf "${FTL_DIR}/${CONFIGURATION}-iphoneos"
rm -rf "${FTL_DIR}/temp"
mkdir -p "${FTL_DIR}/${CONFIGURATION}-iphoneos"
mkdir -p "${FTL_DIR}/temp"

unzip -q -o ${ZIP_DIR}/${TEST_ARTIFACT} -d ${FTL_DIR}/temp

# Prepare FTL-compliant package structure
cp -a ${FTL_DIR}/temp/${TEST_TARGET}_iphoneos.xctestrun ${FTL_DIR}
cp -a ${FTL_DIR}/temp/${TwilioVoiceClient}* ${FTL_DIR}/${CONFIGURATION}-iphoneos

pushd ${FTL_DIR}
zip --quiet -r "${FTL_DIR}/${CONFIGURATION}-iphoneos-${TEST_HOST}.zip" "${CONFIGURATION}-iphoneos" "${TEST_TARGET}_iphoneos.xctestrun"
popd

echo "Preparing for gcloud..."
gcloud components update
gcloud version
gcloud config set project ${FTL_PROJECT_VOICE_APP}
gcloud config set billing/quota_project ${FTL_PROJECT_VOICE_APP}
gcloud auth activate-service-account ${FTL_JENKINS_ACCOUNT} \
       --key-file=../jenkins-ftl.json

RECORD_VIDEO_FLAG="--no-record-video"
if [ "${TEST_HOST}" = "TwilioVoiceUITestsHost" ]; then
  RECORD_VIDEO_FLAG="--record-video"
fi

echo "Executing tests..."
if gcloud -q firebase test ios run \
       --project ${FTL_PROJECT_VOICE_APP} \
       $RECORD_VIDEO_FLAG \
       --xcode-version 9.4.1 \
       --test ${FTL_DIR}/${CONFIGURATION}-iphoneos-${TEST_HOST}.zip \
       ftl/ftl.yaml:TwilioVoiceClient-IntegrationTests
then
  echo "Test matrix successfully finished"
else
  case $RESULT in
    0)
      echo "All test executions passed."
      ;;
    1)
      echo "A general failure occurred. Possible causes include: a filename that does not exist or an HTTP/network error."
      ;;
    2)
      echo "Testing exited because unknown commands or arguments were provided."
      ;;
    10)
      echo "One or more test cases (tested classes or class methods) within a test execution did not pass."
      ;;
    15)
      echo "Firebase Test Lab could not determine if the test matrix passed or failed, because of an unexpected error."
      ;;
    19)
      echo "The test matrix was canceled by the user."
      ;;
    20)
      echo "A test infrastructure error occurred."
      ;;
    *)
      echo "Unexpected exit code."
      ;;
  esac
fi
