#!/bin/bash

source `dirname $0`/env.sh

BASE_DIR=`dirname $0`
pushd "$BASE_DIR"/.. >/dev/null

# setup output dir layout
WORKSPACE_ROOT_DIR=`pwd`

BUILD_HOME_DIR="$WORKSPACE_ROOT_DIR/Autobuild-Testapp"
IOS_PROJECT_NAME="ProgrammableVoiceTestapp"
IOS_SCHEME_NAME="${IOS_PROJECT_NAME}-workspace"
IOS_IPA_NAME="${BUILD_HOME_DIR}"/"${IOS_PROJECT_NAME}.ipa"

# Generating size evaluation report
echo "Generating size evaluation report..."
pushd $IOS_IPA_NAME >/dev/null

# Determine uncompressed TwilioVoice impact
echo 'Determine uncompressed TwilioVoice impact...'
TWILIOVOICE_FRAMEWORK_SIZE_IPHONE8_FAMILY=$(unzip -l "Apps/${IOS_SCHEME_NAME}-iPhone 8-etc.ipa" | grep "Frameworks/Twilio" | cut -c1-9 | awk '{s+=$0}END{print s}' | gnumfmt --to=iec-i --suffix=B --padding=7)
TWILIOVOICE_FRAMEWORK_SIZE_UNIVERSAL=$(unzip -l "Apps/${IOS_SCHEME_NAME}.ipa" | grep "Frameworks/Twilio" | cut -c1-9 | awk '{s+=$0}END{print s}' | gnumfmt --to=iec-i --suffix=B --padding=7)
# Determine uncompressed size for all but TwilioVoice
echo 'Determine uncompressed size for all but TwilioVoice...'
APPLICATION_WITHOUT_TWILIOVOICE_IPHONE8_FAMILY=$(unzip -l "Apps/${IOS_SCHEME_NAME}-iPhone 8-etc.ipa" | grep -- "-201" | grep -v "Frameworks/Twilio" | cut -c1-9 | awk '{s+=$0}END{print s}' | gnumfmt --to=iec-i --suffix=B --padding=7)
APPLICATION_WITHOUT_TWILIOVOICE_UNIVERSAL=$(unzip -l "Apps/${IOS_SCHEME_NAME}.ipa" | grep -- "-201" | grep -v "Frameworks/Twilio" | cut -c1-9 | awk '{s+=$0}END{print s}' | gnumfmt --to=iec-i --suffix=B --padding=7)

# Extract size estimation from the "App Thinning Size Report.txt"
# Assuming the report format looks like this:
#   Variant: ProgrammableVoiceTestapp-workspace-iPhone 8-etc.ipa
#   Supported devices: iPhone 7 and iPhone 8
#   App + On Demand Resources size: 4.2 MB compressed, 9.2 MB uncompressed
#   App size: 4.2 MB compressed, 9.2 MB uncompressed
#   On Demand Resources size: Zero KB compressed, Zero KB uncompressed
SIZE_STRING=$(grep -n -3 "iPhone 8-etc.ipa" "App Thinning Size Report.txt" | grep "App size")
SIZE_STRING_COMPRESSED=${SIZE_STRING% compressed*}
SIZE_STRING_UNCOMPRESSED=${SIZE_STRING% uncompressed*}
COMPRESSED_DOWNLOAD_APP_SIZE_IPHONE8_FAMILY=${SIZE_STRING_COMPRESSED##*:}
UNCOMPRESSED_DOWNLOAD_APP_SIZE_IPHONE8_FAMILY=${SIZE_STRING_UNCOMPRESSED##*,}

SIZE_STRING=$(grep -n -3 "${IOS_SCHEME_NAME}.ipa" "App Thinning Size Report.txt" | grep "App size")
SIZE_STRING_COMPRESSED=${SIZE_STRING% compressed*}
SIZE_STRING_UNCOMPRESSED=${SIZE_STRING% uncompressed*}
COMPRESSED_DOWNLOAD_APP_SIZE_UNIVERSAL=${SIZE_STRING_COMPRESSED##*:}
UNCOMPRESSED_DOWNLOAD_APP_SIZE_UNIVERSAL=${SIZE_STRING_UNCOMPRESSED##*,}

SIZE_REPORT_FILE='size-evaluation.txt'
cat <<EOM >$SIZE_REPORT_FILE
TwilioVoice framework size report (\`$SDK_PRE_RELEASE_VERSION-$SDK_SOURCE_CODE_REVISION\`)
\`\`\`
Impact on arm64 iPhone device thinned binary:
- Compressed download application size: ${COMPRESSED_DOWNLOAD_APP_SIZE_IPHONE8_FAMILY}
- Uncompressed application size: ${UNCOMPRESSED_DOWNLOAD_APP_SIZE_IPHONE8_FAMILY}
- Uncompressed size of Twilio frameworks: ${TWILIOVOICE_FRAMEWORK_SIZE_IPHONE8_FAMILY}
- Uncompressed size of rest of application: ${APPLICATION_WITHOUT_TWILIOVOICE_IPHONE8_FAMILY}
Impact on non-thinned multiple architecture binary:
- Compressed download application size: ${COMPRESSED_DOWNLOAD_APP_SIZE_UNIVERSAL}
- Uncompressed application size: ${UNCOMPRESSED_DOWNLOAD_APP_SIZE_UNIVERSAL}
- Uncompressed size of Twilio frameworks: ${TWILIOVOICE_FRAMEWORK_SIZE_UNIVERSAL}
- Uncompressed size of rest of application: ${APPLICATION_WITHOUT_TWILIOVOICE_UNIVERSAL}
\`\`\`
EOM

popd >/dev/null