#!/bin/bash -e -x

source `dirname $0`/env.sh
cd `dirname $0`/..

export RELEASE_TYPE=${RELEASE_TYPE:-"GA"}

if ! [[ "${VERSION}" =~ ^[0-9]+\.[0-9]+\.[0-9]+$ ]]; then
  echo "VERSION '${VERSION}' must be of format: major.minor.patch"
  exit 1
fi

if [ ${RELEASE_TYPE} == 'BETA' ]; then
    if [ -z "${PRERELEASE_QUALIFIER}" ]; then
        echo "PRERELEASE_QUALIFIER must be set"
        exit 1
    fi

    if ! [[ "${PRERELEASE_QUALIFIER}" =~ ^preview[0-9]+$ ]] && ! [[ "${PRERELEASE_QUALIFIER}" =~ ^beta[0-9]+$ ]]; then
        echo "PRERELEASE_QUALIFIER '${PRERELEASE_QUALIFIER}' doesn't look like a supported value."
        exit 1
    fi

    RELEASE_VERSION_STRING=${VERSION}-${PRERELEASE_QUALIFIER}
elif [ ${RELEASE_TYPE} == 'GA' ]; then
  if [ ! -z "${PRERELEASE_QUALIFIER}" ]; then
      echo "PRERELEASE_QUALIFIER must not be provided"
      exit 1
  fi
  
    RELEASE_VERSION_STRING=${VERSION}
else
    echo "Unknown Release type" ${RELEASE_TYPE}. "Supported release types are BETA and GA"
    exit 1
fi

PODSPEC_URL="https://media.twiliocdn.com/sdk/${ARTIFACT_PLATFORM}/${ARTIFACT_NAME}/releases/${RELEASE_VERSION_STRING}/${PODSPEC_NAME}"

VERSION_EXISTS=1
curl -s -f -I -X HEAD "${PODSPEC_URL}" 2>&1 > /dev/null || VERSION_EXISTS=0

if [ "0" == "${VERSION_EXISTS}" ]; then
  echo "##### WARNING: Cannot publish a non existing version"
  exit 1
fi

TEMP_DIR=temp/pod
PODSPEC_PATH="${TEMP_DIR}/${PODSPEC_NAME}"

rm -rf $TEMP_DIR
mkdir -p $TEMP_DIR

curl -s -f "${PODSPEC_URL}" -o "${PODSPEC_PATH}"

pod trunk push "${PODSPEC_PATH}"