#!/bin/bash -e -x

export PATH=/usr/local/bin:$PATH

pushd `dirname $0`/..

FTL=${RUN_TESTS_ON_FTL:-0}
if [ "${FTL}" = 1 ]; then
  echo "Running tests on FTL.."

  # determine bitcode generation mode. We only want full bitcode segments for release builds
  BITCODE_MODE=marker
  if [ "${CONFIGURATION}" = "Release" ]; then
    BITCODE_MODE=bitcode
  fi

  # First build the test host UI app for dismissing device popups
  echo "Build TwilioVoice tests host..."
  xcodebuild ${VERSION_INFO} \
    -project TwilioVoiceClient/TwilioVoiceClient.xcodeproj \
    -scheme TwilioVoiceClientTestHost \
    -derivedDataPath ${DERIVED_DATA_DIR} \
    -configuration ${CONFIGURATION} \
    -sdk iphoneos \
    -parallelizeTargets \
    ONLY_ACTIVE_ARCH=NO \
    BITCODE_GENERATION_MODE=${BITCODE_MODE} \
    build-for-testing

  # Move the xctestrun files so they don't get overwritten
  mv ${BUILD_DIR}/TwilioVoiceClientTestHost_iphoneos*.xctestrun ${BUILD_DIR}/${CONFIGURATION}-iphoneos/TwilioVoiceClientTestHost_iphoneos.xctestrun

  # Now build the UI integration test host UI app for dismissing device popups
  echo "Build TwilioVoice UI integration tests host..."
  xcodebuild ${VERSION_INFO} \
    -project TwilioVoiceClient/TwilioVoiceClient.xcodeproj \
    -scheme TwilioVoiceUITestsHost \
    -derivedDataPath ${DERIVED_DATA_DIR} \
    -configuration ${CONFIGURATION} \
    -sdk iphoneos \
    -parallelizeTargets \
    ONLY_ACTIVE_ARCH=NO \
    BITCODE_GENERATION_MODE=${BITCODE_MODE} \
    build-for-testing

  # Move the xctestrun files so they don't get overwritten
  mv ${BUILD_DIR}/TwilioVoiceUITestsHost_iphoneos*.xctestrun ${BUILD_DIR}/${CONFIGURATION}-iphoneos/TwilioVoiceUITestsHost_iphoneos.xctestrun

  # Build TwilioVoice tests for FTL
  echo "Build TwilioVoice tests for FTL..."
  for env in iphoneos; do
    xcodebuild ${VERSION_INFO} \
      -project TwilioVoiceClient/TwilioVoiceClient.xcodeproj \
      -scheme TwilioVoiceClient \
      -derivedDataPath ${DERIVED_DATA_DIR} \
      -configuration ${CONFIGURATION} \
      -sdk ${env} \
      -parallelizeTargets \
      ONLY_ACTIVE_ARCH=NO \
      BITCODE_GENERATION_MODE=${BITCODE_MODE} \
      build-for-testing

    # Manually append tests to be skipped on FTL and move the xctestrun files so they don't get overwritten
    DERIVED_XCTESTRUN_FILE=${BUILD_DIR}/TwilioVoiceClient_${env}*.xctestrun
    XCTESTRUN_FILE=${BUILD_DIR}/${CONFIGURATION}-${env}/TwilioVoiceClient_${env}.xctestrun
    ADDITIONAL_SKIPPED_TESTS=$(<Scripts/additional-skipped-tests.txt)
    CONTENTS=$(echo $ADDITIONAL_SKIPPED_TESTS | sed 's/\//\\\//g')
    sed "/testUnregisterWithNullPushCreds<\/string>/s/.*/&${CONTENTS}/" ${DERIVED_XCTESTRUN_FILE} | tr '|' '\n' | tr '*' '\t' > ${XCTESTRUN_FILE}
  done

  # Build TwilioVoice UI-integration tests for FTL
  echo "Build TwilioVoice UI-integration tests for FTL..."
  for env in iphoneos; do
    xcodebuild ${VERSION_INFO} \
      -project TwilioVoiceClient/TwilioVoiceClient.xcodeproj \
      -scheme TwilioVoiceUIIntegrationTests \
      -derivedDataPath ${DERIVED_DATA_DIR} \
      -configuration ${CONFIGURATION} \
      -sdk ${env} \
      -parallelizeTargets \
      ONLY_ACTIVE_ARCH=NO \
      BITCODE_GENERATION_MODE=${BITCODE_MODE} \
      build-for-testing
  done

  # Prepare package for FTL tests
  rm -rf "${ZIP_DIR}"
  mkdir -p "${ZIP_DIR}"

  # Prepare package for upload
  for env in iphoneos; do
    pushd ${BUILD_DIR}/${CONFIGURATION}-${env}
      zip --quiet -r "${ZIP_DIR}/${CONFIGURATION}-${env}-TwilioVoiceClientTestHost.zip" TwilioVoiceClientTestHost* "TwilioVoiceClient_${env}.xctestrun" TwilioVoiceUITests-Runner.app
    popd
  done

  # Prepare package for upload (UI integration tests)
  for env in iphoneos; do
    pushd ${BUILD_DIR}/${CONFIGURATION}-${env}
      zip --quiet -r "${ZIP_DIR}/${CONFIGURATION}-${env}-TwilioVoiceUITestsHost.zip" TwilioVoiceUITestsHost* "TwilioVoiceUITestHost_${env}.xctestrun" TwilioVoiceUIIntegrationTests-Runner.app
    popd
  done

  pushd Scripts
  echo "Executing tests on FTL..."
  ./execute-ftl-test.sh TwilioVoiceClientTestHost TwilioVoiceClient

  echo "Executing UI integration tests on FTL..."
  ./execute-ftl-test.sh TwilioVoiceUITestsHost TwilioVoiceUITestsHost
  popd
fi

popd
